@@ -80,10 +80,10 @@ symbck(){
       strcpy(caj[0], "|f");	strcpy(caz[0], wd);	ct = 1;	return;
     }
     if(strcmp(wd, "[") == 0 || strcmp(wd, "(") == 0){
-      strcpy(caj[0], "|(");	ct = 1;	return;
+      strcpy(caj[0], "|[");	ct = 1;	return;
     }
     if(strcmp(wd, "]") == 0 || strcmp(wd, ")") == 0){
-      strcpy(caj[0], "|)");	ct = 1;	return;
+      strcpy(caj[0], "|]");	ct = 1;	return;
     }
     if(strcmp(wd, "+") == 0){
       strcpy(caj[0], "0{");	strcpy(caz[0], wd);	ct = 1;	return;
@@ -148,6 +148,7 @@ digit(){
     }
     if(ln > 2 && (strcmp(wd+ln-2, "th") == 0 || strcmp(wd+ln-2, "st") == 0
     || strcmp(wd+ln-2, "nd") == 0 || strcmp(wd+ln-2, "rd") == 0)){
+ if(Dbg == 'Y') fprintf(dbg, "--- digit --- wd = %s \n", wd);
       strcpy(dums, wd);
       *(dums+ln-2) = '\0';	nhantozen(dums, zenkaku);
       *caj[0] = '\0';
