@@ -9,7 +9,7 @@
 
 char *dir = "/usr/home/murase/c/yak/";
 
-FILE *fpin, *fpout, *prcs, *dbg;
+FILE *fpin, *fpout, *prcs, *dbg, *wdr;
 extern FILE *ejd;
 char buf[SentLen+20000], path[170], path_in[170], path2[170];
 extern char aj[WordNumb][YakugoMax][JWordLen], az[WordNumb][YakugoMax][ZokuLen];
@@ -96,7 +96,10 @@ char *argv[];
     ejd = fopen(ejdic, "r");
     setUp();
     zbClear();
-    if(Dbg == 'Y') dbg = fopen("DEBUG.YAK", "w");
+    if(Dbg == 'Y'){ dbg = fopen("DEBUG.YAK", "w");
+      wdr = fopen("WDREG", "w");
+      fprintf(wdr, "{ꕶR[hS_JISw C-x RET f shift_jis\n");
+    }
     strcpy(process, "PROCESS.YAK");
 //    sprintf(process, "%sPROCESS.YAK", dir);
 //    prcs = fopen("PROCESS.YAK", "w");
@@ -134,7 +137,7 @@ char *argv[];
   MAI2:
     printf("End of file reached\n");
     if(LOG == 'Y') fclose(prcs);
-    if(Dbg == 'Y') fclose(dbg);
+    if(Dbg == 'Y'){ fclose(dbg); fclose(wdr);    }
     fclose(fpin);	fclose(fpout);	fclose(ejd);
     if(existence == 0){ printf("Sentence not exist!\n");  exit(1); }
     resave();
@@ -622,6 +625,9 @@ int  *cs;
     }*/
     Conj(wdp, wdh, cs);
  if(Dbg == 'Y') fprintf(dbg, "--- jishoFail --- wdh = %s *cs = %d  zkc = %c \n", wdh, *cs, zkc);
+    if(*cs == 9)
+      if(Dbg == 'Y') fprintf(wdr, "%s:::\n", wd); // 16/5/22
+
     if(zkc == '\0' || (zkc == 'K' && wc == -1)){
       engcopy();
 	strcpy(wdx, wd);	strcpy(wdw, wdh);
