@@ -80,8 +80,9 @@ bunpo(){
     if(ume == 0) ume = instrc(csq, '*');
     ume1 = ume+1;
     while(ume){
- if(Dbg == 'Y') printf("--- bunpo --- %s %d \n", csq, ume);
-// printf("--- bunpo --- csq = %s ume = %d \n", csq, ume);
+ if(Dbg == 'Y') fprintf(dbg, "--- bunpo --- csq = %s ume = %d \n", csq, ume);
+ if(Dbg == 'Y') fprintf(dbg, "--- bunpo --- *csq+ume = %s \n", csq+ume);
+
       if(csq[ume] == '#' || csq[ume1] == '#' || csq[ume1] == '*' ||
       csq[ume1] == '\0' || csq[ume] == '\0'){
 	left(qmk, cz[ume-1], 2);	ct = 0;
@@ -793,8 +794,8 @@ char qmk[];
 {
     int  t, jm;
     char umw[JSentLen], *pm, *pju;
- if(Dbg == 'Y') printf("--- umekomi --- qmk = %s \n", qmk);
-// printf("--- umekomi --- qmk = %s \n", qmk);
+ if(Dbg == 'Y') fprintf(dbg, "--- umekomi --- qmk = %s \n", qmk);
+
     left(qmk, cz[ume-1], 2);
     if(*qmk == '*') *qmk = '%';
     for(t = ume-2; t >= 0; t--){
