@@ -173,6 +173,7 @@ char *pt;
     }
     if(strcmp(cmd, "&T") == 0){
   if(Dbg == 'Y') fprintf(dbg, "--- &T --- i = %d md = %s mz = %s \n", i, md[i], mz[i]);
+      if(strchr(mz[i], 'K') && strchr(mz[i], 'h')) return;
       if(strstr(md[i]+1, "wh") && !strstr(md[i]+1, "whi") && strncmp(md[i]+1, "wh", 2) != 0) return;
       if(strncmp(md[i]+1, "whether ", 8) == 0) return;
       if(strncmp(md[i]+1, "many ", 5) == 0) return;
@@ -435,6 +436,7 @@ char mdi[], mzi[], mdj[], mzj[];
     if(strncmp(mdi+1, "would ", 6) == 0) return;
     if(strncmp(mdi+1, "almost ", 7) == 0) return;
     if(strncmp(mdi+1, "there are", 9) == 0) return;
+    if(strncmp(mdi+1, "there is", 8) == 0) return;
     if(strncmp(mdi+1, "there be", 8) == 0 ){
       if(strstr(mzj, "") || strchr(mzj, 'n') ){
 	ptreplace(mdi+7, 2, "are");    return;
@@ -625,6 +627,13 @@ char *str, *ptone;
         ptreplace(ptone, 5, "their");    return;
       }
     }
+
+    if(strncmp(ptone, "one ", 4) == 0) {
+      if(!strcmp(str, "I") || !strcmp(str, "me")){
+        ptreplace(ptone, 4, "I ");    return;
+      }
+    }
+
 }
 
 sinko(md)
